@@ -30,13 +30,11 @@ from __future__ import print_function, absolute_import, division, unicode_litera
 # Read comments in the Scanner code for more details.
 #
 
-import sys
-
 from ruamel.yaml.error import MarkedYAMLError
 from ruamel.yaml.tokens import *                # NOQA
 from ruamel.yaml.compat import utf8, unichr, PY3, check_anchorname_char
 
-if sys.version_info >= (3, 5, 2):
+if False:  # MYPY
     from typing import Any, Dict, Optional, List, Union, Text  # NOQA
 
 __all__ = ['Scanner', 'RoundTripScanner', 'ScannerError']
@@ -74,7 +72,7 @@ class Scanner(object):
         #   self.forward(l=1) # read the next l characters and move the pointer
 
         self.loader = loader
-        if self.loader is not None:
+        if self.loader is not None and getattr(self.loader, '_scanner', None) is None:
             self.loader._scanner = self
 
         # Had we reached the end of the stream?
@@ -132,7 +130,9 @@ class Scanner(object):
     @property
     def reader(self):
         # type: () -> Any
-        return self.loader._reader
+        if hasattr(self.loader, 'typ'):
+            self.loader.reader  # type: ignore
+        return self.loader._reader  # type: ignore
 
     # Public methods.
 
