@@ -56,12 +56,16 @@ class Serializer(object):
     @property
     def emitter(self):
         # type: () -> Any
-        return self.dumper._emitter
+        if hasattr(self.dumper, 'typ'):
+            return self.dumper.emitter  # type: ignore
+        return self.dumper._emitter  # type: ignore
 
     @property
     def resolver(self):
         # type: () -> Any
-        return self.dumper._resolver
+        if hasattr(self.dumper, 'typ'):
+            self.dumper.resolver  # type: ignore
+        return self.dumper._resolver  # type: ignore
 
     def open(self):
         # type: () -> None
